@@ -53,14 +53,16 @@ import yaml
 
 
 def pytest_configure(config):
-    if config.option.base_url:
-        status_code = _get_status_code(config.option.base_url)
-        assert status_code == 200, 'Base URL did not return status code 200. (URL: %s, Response: %s)' % (config.option.base_url, status_code)
+    if not hasattr(config, 'slaveinput'):
 
-    report_path = config.option.webqa_report_path
-    if report_path:
-        config._html = LogHTML(report_path, config)
-        config.pluginmanager.register(config._html)
+        if config.option.base_url:
+            status_code = _get_status_code(config.option.base_url)
+            assert status_code == 200, 'Base URL did not return status code 200. (URL: %s, Response: %s)' % (config.option.base_url, status_code)
+    
+        report_path = config.option.webqa_report_path
+        if report_path:
+            config._html = LogHTML(report_path, config)
+            config.pluginmanager.register(config._html)
 
 
 def pytest_unconfigure(config):
@@ -292,7 +294,8 @@ def _get_common_sauce_settings(item):
     return {'build': item.config.option.build or None,
             'name': '.'.join(_split_class_and_test_names(item.nodeid)),
             'tags': tags,
-            'public': False}
+            'public': True,
+            'restricted-public-info': True}
 
 
 def _start_selenium(item):
@@ -474,11 +477,10 @@ class LogHTML(object):
         self.passed = self.skipped = 0
         self.failed = self.failed = 0
         self.xfailed = self.xpassed = 0
-        self._durations = {}
 
     def _appendrow(self, result, report):
         (classname, testname) = _split_class_and_test_names(report.nodeid)
-        time = self._durations.pop(report.nodeid, 0.0)
+        time = getattr(report, 'duration', 0.0)
         session_id = self._get_session_id(report)
         links = {'HTML': self._get_debug_filename(report, 'html'),
                  'Screenshot': self._get_debug_filename(report, 'png')}
@@ -621,13 +623,6 @@ class LogHTML(object):
         elif report.skipped:
             self.append_skipped(report)
 
-    def pytest_runtest_call(self, item, __multicall__):
-        start = time.time()
-        try:
-            return __multicall__.execute()
-        finally:
-            self._durations[item.nodeid] = time.time() - start
-
     def pytest_sessionstart(self, session):
         self.suite_start_time = time.time()
 
